from django.urls import path
from django.views.generic import TemplateView

app_name = "djbookshelf"


class DashBoard(TemplateView):
    template_name = "djbookshelf/core.html"


urlpatterns = [
    path("dashboard/", DashBoard.as_view(), name="dashboard"),
    path(
        "",
        DashBoard.as_view(),
    ),
]



from django.db import models
import logging

log = logging.getLogger(__name__)


class Language(models.Model):
    name = models.CharField(max_length=300, unique=True)

    def __str__(self):
        return self.name



# Generated by Django 3.2.10 on 2021-12-28 22:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("djbookshelf", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Language",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=300, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="Publisher",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=300, unique=True)),
            ],
        ),
        migrations.RenameField(
            model_name="isbn",
            old_name="searched_google",
            new_name="searched",
        ),
        migrations.RemoveField(
            model_name="book",
            name="author",
        ),
        migrations.AddField(
            model_name="book",
            name="authors",
            field=models.ManyToManyField(to="djbookshelf.Author"),
        ),
        migrations.AddField(
            model_name="book",
            name="year",
            field=models.CharField(blank=True, max_length=6, null=True),
        ),
        migrations.AddField(
            model_name="book",
            name="language",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="djbookshelf.language",
            ),
        ),
        migrations.AddField(
            model_name="book",
            name="publisher",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="djbookshelf.publisher",
            ),
        ),
    ]



from django.db import models

from djbookshelf.exceptions import ISBNNoBookFoundException
from djbookshelf.models.author import Author
from djbookshelf.models.book import Book
from djbookshelf.models.publisher import Publisher
from djbookshelf.models.language import Language
from djbookshelf.utility import get_book_from_isbn
import logging

log = logging.getLogger(__name__)


class ISBN(models.Model):
    isbn = models.CharField(max_length=13, blank=True, null=True)
    book = models.ForeignKey(
        "Book", on_delete=models.CASCADE, null=True, blank=True
    )
    searched = models.BooleanField(default=False)

    def __str__(self):
        if self.book:
            return self.isbn
        return f"{self.isbn} - {self.book}"

    def elaborate(self) -> (bool, bool):
        if not self.searched:
            flag = False
            try:
                data = get_book_from_isbn(self.isbn)
                if data.get("language", "") != "":
                    language, _ = Language.objects.get_or_create(
                        name=data["language"]
                    )
                else:
                    language = None
                if data.get("publisher", "") != "":
                    publisher, _ = Publisher.objects.get_or_create(
                        name=data["publisher"]
                    )
                else:
                    publisher = None
                book = Book.objects.create(
                    title=data["title"],
                    image=data["image"],
                    year=data["publication_date"],
                    publisher=publisher,
                    language=language,
                )
                self.book = book
                for a in data["authors"]:
                    author, _ = Author.objects.get_or_create(name=a)
                    book.authors.add(author)
                flag = True
                book.save()
            except ISBNNoBookFoundException:
                log.error(f"{self.isbn} not found")
                flag = False
            self.searched = True
            self.save()
            return True, flag
        return False, False



from typing import Union

from django.db import models
from isbnlib import meta, cover, NotValidISBNError

from djbookshelf.exceptions import ISBNNoBookFoundException

ISBN_SEARCH = ["goob", "openl", "wiki"]


def get_data_book(isbn: str) -> dict:
    try:
        for engine in ISBN_SEARCH:
            data = meta(isbn, engine)
            if data != {}:
                return data
        raise ISBNNoBookFoundException
    except NotValidISBNError:
        raise ISBNNoBookFoundException


def get_book_from_isbn(isbn: Union[str, models.CharField]) -> dict:
    image = None
    cover_data = cover(isbn)
    if cover_data.get("thumbnail", None):
        image = cover_data["thumbnail"]
    elif cover_data.get("smallThumbnail", None):
        image = cover_data["smallThumbnail"]

    data = get_data_book(isbn)

    return {
        "title": data.get("Title", ""),
        "authors": data.get("Authors", []),
        "publication_date": data.get("Year", ""),
        "image": image,
        "language": data.get("Language", ""),
        "publisher": data.get("Publisher", ""),
    }



from django.db import models

import logging

log = logging.getLogger(__name__)


class Book(models.Model):
    title = models.CharField(max_length=300, null=True, blank=True)
    authors = models.ManyToManyField("Author")
    language = models.ForeignKey(
        "Language", null=True, blank=True, on_delete=models.CASCADE
    )
    publisher = models.ForeignKey(
        "Publisher", null=True, blank=True, on_delete=models.CASCADE
    )
    year = models.CharField(max_length=6, null=True, blank=True)
    image = models.URLField(null=True, blank=True)

    room = models.CharField(max_length=200, blank=True, null=True)
    shelf = models.CharField(max_length=200, blank=True, null=True)
    book_code = models.CharField(max_length=200, blank=True, null=True)

    def __str__(self):
        return f"{self.author} - {self.title}"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['djbookshelf', 'djbookshelf.migrations', 'djbookshelf.models']

package_data = \
{'': ['*'], 'djbookshelf': ['templates/djbookshelf/*']}

install_requires = \
['django-bootstrap-v5>=1.0.7,<2.0.0',
 'django>=3.2,<5',
 'isbnlib>=3.10.9,<4.0.0',
 'requests>=2,<3']

setup_kwargs = {
    'name': 'djbookshelf',
    'version': '0.1.4',
    'description': '',
    'long_description': '# DjBookShelf\n\nThis is a Django module for manage books\n\nYou can find the [documentation here](https://djbookshelf.readthedocs.io/en/latest/)\n',
    'author': 'Fundor333',
    'author_email': 'fundor333@fundor333.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://djbookshelf.readthedocs.io/en/latest/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from djbookshelf.models.author import Author
from djbookshelf.models.isbn import ISBN
from djbookshelf.models.language import Language
from djbookshelf.models.publisher import Publisher
from djbookshelf.models.book import Book

__all__ = ("Author", "ISBN", "Language", "Publisher", "Book")



# Generated by Django 4.0 on 2021-12-28 12:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Author",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=300, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="Book",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "title",
                    models.CharField(blank=True, max_length=300, null=True),
                ),
                ("image", models.URLField(blank=True, null=True)),
                (
                    "room",
                    models.CharField(blank=True, max_length=200, null=True),
                ),
                (
                    "shelf",
                    models.CharField(blank=True, max_length=200, null=True),
                ),
                (
                    "book_code",
                    models.CharField(blank=True, max_length=200, null=True),
                ),
                (
                    "author",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="djbookshelf.author",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="ISBN",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "isbn",
                    models.CharField(blank=True, max_length=13, null=True),
                ),
                ("searched_google", models.BooleanField(default=False)),
                (
                    "book",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="djbookshelf.book",
                    ),
                ),
            ],
        ),
    ]
